@@ -9,14 +9,19 @@ QMainWindow(parent),
     ui(new Ui::ProfileChangerWidget)
 {
     ui->setupUi(this);
+    QPalette palette;
     setAttribute(Qt::WA_TranslucentBackground);
-    if (!QSettings().contains("profilechangerwidget/width"))
-        QSettings().setValue("profilechangerwidget/width", 48);
-    if (!QSettings().contains("profilechangerwidget/height"))
-        QSettings().setValue("profilechangerwidget/height", 48);
+    ui->centralWidget->setAttribute(Qt::WA_TranslucentBackground);
+    ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
+    palette.setColor(QPalette::Base, Qt::transparent);
+    ui->centralWidget->setPalette(palette);
+    QSettings settings;
+    if (!settings.contains("profilechangerwidget/width"))
+        settings.setValue("profilechangerwidget/width", 48);
+    if (!settings.contains("profilechangerwidget/height"))
+        settings.setValue("profilechangerwidget/height", 48);
 
     connect(ui->switchButton, SIGNAL(clicked()), this, SLOT(onChangeProfileClicked()));
-    ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
     this->reloadSettings();
 }
 
@@ -104,9 +109,10 @@ void ProfileChangerWidget::onHomeScreenChanged(bool isOnCurrentHomescreen)
 
 void ProfileChangerWidget::reloadSettings()
 {
+    QSettings settings;
     this->setGeometry(this->x(), this->y(),
-                      QSettings().value("profilechangerwidget/width").toInt(),
-                      QSettings().value("profilechangerwidget/height").toInt());
+                      settings.value("profilechangerwidget/width").toInt(),
+                      settings.value("profilechangerwidget/height").toInt());
     this->refreshIcon();
 }
 
